@@ -5,11 +5,13 @@ using ReTestItems, SCCNonlinearSolve, Hwloc, InteractiveUtils, Pkg
 const GROUP = lowercase(get(ENV, "GROUP", "All"))
 
 const RETESTITEMS_NWORKERS = parse(
-    Int, get(ENV, "RETESTITEMS_NWORKERS",
+    Int, get(
+        ENV, "RETESTITEMS_NWORKERS",
         string(min(ifelse(Sys.iswindows(), 0, Hwloc.num_physical_cores()), 4))
     )
 )
-const RETESTITEMS_NWORKER_THREADS = parse(Int,
+const RETESTITEMS_NWORKER_THREADS = parse(
+    Int,
     get(
         ENV, "RETESTITEMS_NWORKER_THREADS",
         string(max(Hwloc.num_virtual_cores() ÷ max(RETESTITEMS_NWORKERS, 1), 1))
